/*
 * Ext JS Library 2.1
 * Copyright(c) 2006-2008, Ext JS, LLC.
 * licensing@extjs.com
 * 
 * http://extjs.com/license
 */

Ext.UpdateManager.defaults.indicatorText="<div class=\"loading-indicator\">��?�込�?��...</div>";if(Ext.View){Ext.View.prototype.emptyText=""}if(Ext.grid.Grid){Ext.grid.Grid.prototype.ddText="{0} 行�?�択"}if(Ext.TabPanelItem){Ext.TabPanelItem.prototype.closeText="�?��?�タブを閉�?�る"}if(Ext.form.Field){Ext.form.Field.prototype.invalidText="フィールド�?�値�?��?��?��?�。"}if(Ext.LoadMask){Ext.LoadMask.prototype.msg="��?�込�?��..."}Date.monthNames=["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"];Date.dayNames=["日","月","�?�","水","木","金","土"];if(Ext.MessageBox){Ext.MessageBox.buttonText={ok:"OK",cancel:"�ャンセル",yes:"�?��?�",no:"�?��?��?�"}}if(Ext.util.Format){Ext.util.Format.date=function(A,B){if(!A){return""}if(!(A instanceof Date)){A=new Date(Date.parse(A))}return A.dateFormat(B||"Y/m/d")}}if(Ext.DatePicker){Ext.apply(Ext.DatePicker.prototype,{todayText:"今日",minText:"�?�択�?��?�日付�?�最�?値以下�?��?�。",maxText:"�?�択�?��?�日付�?�最大値以上�?��?�。",disabledDaysText:"",disabledDatesText:"",monthNames:Date.monthNames,dayNames:Date.dayNames,nextText:"次月�?� (コント�ール+�?�)",prevText:"�?月�?� (コント�ール+左)",monthYearText:"月�?�択 (コント�ール+上/下�?�年移動)",todayTip:"{0} (スペース�ー)",format:"Y/m/d"})}if(Ext.PagingToolbar){Ext.apply(Ext.PagingToolbar.prototype,{beforePageText:"ページ",afterPageText:"/ {0}",firstText:"最�?�?�ページ",prevText:"�?�?�ページ",nextText:"次�?�ページ",lastText:"最後�?�ページ",refreshText:"更新",displayMsg:"{2} 件� {0} - {1} を表示",emptyMsg:"表示�?�るデータ�?��?�り�?��?�ん。"})}if(Ext.form.TextField){Ext.apply(Ext.form.TextField.prototype,{minLengthText:"�?��?�フィールド�?�最�?値�?� {0} �?��?�。",maxLengthText:"�?��?�フィールド�?�最大値�?� {0} �?��?�。",blankText:"必須項目�?��?�。",regexText:"",emptyText:null})}if(Ext.form.NumberField){Ext.apply(Ext.form.NumberField.prototype,{minText:"�?��?�フィールド�?�最�?値�?� {0} �?��?�。",maxText:"�?��?�フィールド�?�最大値�?� {0} �?��?�。",nanText:"{0} �?�数値�?��?��?�り�?��?�ん。"})}if(Ext.form.DateField){Ext.apply(Ext.form.DateField.prototype,{disabledDaysText:"無効",disabledDatesText:"無効",minText:"�?��?�フィールド�?�日付�?��? {0} 以�?�?�日付�?��定�?��?��??�?��?��?�。",maxText:"�?��?�フィールド�?�日付�?��? {0} 以�?�?�日付�?��定�?��?��??�?��?��?�。",invalidText:"{0} �?�間�?��?��?�日付入力�?��?�。 - 入力形�?�?�「{1}�?�?��?�。",format:"Y/m/d"})}if(Ext.form.ComboBox){Ext.apply(Ext.form.ComboBox.prototype,{loadingText:"��?�込�?��...",valueNotFoundText:undefined})}if(Ext.form.VTypes){Ext.apply(Ext.form.VTypes,{emailText:"メールアドレスを\"user@domain.com\"�?�形�?�?�入力�?��?��??�?��?��?�。",urlText:"URLを\"http:/"+"/www.domain.com\"�?�形�?�?�入力�?��?��??�?��?��?�。",alphaText:"�?�角英��?�\"_\"�?��?��?��?�。",alphanumText:"�?�角英数�?�\"_\"�?��?��?��?�。"})}if(Ext.grid.GridView){Ext.apply(Ext.grid.GridView.prototype,{sortAscText:"昇順",sortDescText:"�?順",lockText:"カラム�ック",unlockText:"カラム�ック解除",columnsText:"Columns"})}if(Ext.grid.PropertyColumnModel){Ext.apply(Ext.grid.PropertyColumnModel.prototype,{nameText:"�??称",valueText:"値",dateFormat:"Y/m/d"})}if(Ext.layout.BorderLayout.SplitRegion){Ext.apply(Ext.layout.BorderLayout.SplitRegion.prototype,{splitTip:"ドラッグ�?�る�?�リサイズ�?��??�?��?�。",collapsibleSplitTip:"ドラッグ�?�リサイズ。 ダブルクリック�?�隠�?�。"})};